%define upstream_name    Config-Grammar
%define upstream_version 1.13

%{?perl_default_filter}

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 3

Summary:    A grammar-based, user-friendly config parser
License:    GPL+ or Artistic
Group:      Development/Perl
Url:        https://metacpan.org/release/%{upstream_name}
Source0:    https://cpan.metacpan.org/modules/by-module/Config/%{upstream_name}-%{upstream_version}.tar.gz

BuildRequires: perl(ExtUtils::MakeMaker)
BuildRequires: perl(Test)
BuildRequires: perl(Test::Simple)
BuildRequires: perl(base)
BuildRequires: perl(lib)
BuildRequires: perl(strict)
BuildRequires: perl(vars)
BuildArch:  noarch

%description
Config::Grammar is a module to parse configuration files. The configuration
may consist of multiple-level sections with assignments and tabular data.
The parsed data will be returned as a hash containing the whole
configuration. Config::Grammar uses a grammar that is supplied upon
creation of a Config::Grammar object to parse the configuration file and
return helpful error messages in case of syntax errors. Using the *makepod*
method you can generate documentation of the configuration file format.

The *maketmpl* method can generate a template configuration file. If your
grammar contains regexp matches, the template will not be all that helpful
as Config::Grammar is not smart enough to give you sensible template data
based in regular expressions. The related function *maketmplmin* generates
a minimal configuration template without examples, regexps or comments and
thus allows an experienced user to fill in the configuration data more
efficiently.

Grammar Definition
    The grammar is a multiple-level hash of hashes, which follows the
    structure of the configuration. Each section or variable is represented
    by a hash with the same structure. Each hash contains special keys
    starting with an underscore such as '_sections', '_vars', '_sub' or
    '_re' to denote meta data with information about that section or
    variable. Other keys are used to structure the hash according to the
    same nesting structure of the configuration itself. The starting hash
    given as parameter to 'new' contains the "root section".

%prep
%setup -q -n %{upstream_name}-%{upstream_version}

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%make_install

%files
%doc Changes LICENSE META.json META.yml MYMETA.yml README
%{_mandir}/man3/*
%perl_vendorlib/*

%changelog
* Mon Mar 21 2022 umeabot <umeabot> 1.130.0-3.mga9
+ Revision: 1811578
- Mageia 9 Mass Rebuild

* Sat Feb 15 2020 umeabot <umeabot> 1.130.0-2.mga8
+ Revision: 1523992
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%makeinstall_std

* Thu Mar 21 2019 tv <tv> 1.130.0-1.mga7
+ Revision: 1379345
- update to 1.13

* Thu Sep 20 2018 umeabot <umeabot> 1.120.0-2.mga7
+ Revision: 1282343
- Mageia 7 Mass Rebuild

* Sun Jul 30 2017 sander85 <sander85> 1.120.0-1.mga7
+ Revision: 1132694
- update to 1.12

* Sat Jun 18 2016 pterjan <pterjan> 1.110.0-2.mga6
+ Revision: 1024293
- Rebuild for perl 5.22.2

* Fri Apr 15 2016 shlomif <shlomif> 1.110.0-1.mga6
+ Revision: 1001713
- update to 1.11

* Mon Feb 08 2016 umeabot <umeabot> 1.100.0-7.mga6
+ Revision: 943256
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 1.100.0-6.mga5
+ Revision: 740174
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.100.0-5.mga5
+ Revision: 683979
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 1.100.0-4.mga4
+ Revision: 510170
- Mageia 4 Mass Rebuild

* Sun Jan 13 2013 umeabot <umeabot> 1.100.0-3.mga3
+ Revision: 364632
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Jan 21 2011 jquelin <jquelin> 1.100.0-2.mga1
+ Revision: 28642
- remove mdk macros
- mageia rebuild
- imported package perl-Config-Grammar

